Package: Rcollectl
Title: Help use collectl with R in Linux, to measure resource
        consumption in R processes
Version: 1.10.0
Date: 2023-03-08
Authors@R: 
    c(person(given = "Vincent",
           family = "Carey",
           role = c("aut", "cre"),
           email = "stvjc@channing.harvard.edu",
           comment = c(ORCID = "0000-0003-4046-0063")),
      person(given = "Yubo",
           family = "Cheng", 
           role = c("aut"),
           email="yubo.cheng@roswellpark.org"))
Description: Provide functions to obtain instrumentation data on
    processes in a unix environment.  Parse output of a collectl
    run.  Vizualize aspects of system usage over time, with annotation.
Imports: utils, ggplot2, lubridate, processx
License: Artistic-2.0
URL: https://github.com/vjcitn/Rcollectl
BugReports: https://support.bioconductor.org/t/Rcollectl
biocViews: Software, Infrastructure
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.2
SystemRequirements: collectl
Suggests: knitr, BiocStyle, knitcitations, sessioninfo, rmarkdown,
        testthat, covr
VignetteBuilder: knitr
git_url: https://git.bioconductor.org/packages/Rcollectl
git_branch: RELEASE_3_22
git_last_commit: 1a76401
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
Packaged: 2025-10-30 05:58:04 UTC; biocbuild
Author: Vincent Carey [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-4046-0063>),
  Yubo Cheng [aut]
Maintainer: Vincent Carey <stvjc@channing.harvard.edu>
