% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/process.R
\name{cl_start}
\alias{cl_start}
\title{start collectl if possible}
\usage{
cl_start(target = tempfile())
}
\arguments{
\item{target}{character(1) path; destination of collectl report}
}
\value{
instance of \code{Rcollectl_process} with components \code{process} (a processx R6 instance) and
\code{target} (a file path where collectl results will be written)
}
\description{
start collectl if possible
}
\examples{
if (cl_exists()) {
  zz = cl_start()
  Sys.sleep(2)
  print(zz)
  Sys.sleep(2)
  print(cl_result_path(zz))
  cl_stop(zz)
  Sys.sleep(2)
  zz$process$is_alive()
}
}
