% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/process.R
\name{cl_exists}
\alias{cl_exists}
\title{check for collectl availability}
\usage{
cl_exists()
}
\value{
logical(1)
}
\description{
check for collectl availability
}
\examples{
cl_exists()
}
